@@ -35,8 +35,6 @@
 #include "logview-manager.h"
 #include "logview-filter-manager.h"
 
-#include "gtkmessagearea.h"
-
 #define APP_NAME _("System Log Viewer")
 #define SEARCH_START_MARK "lw-search-start-mark"
 #define SEARCH_END_MARK "lw-search-end-mark"
@@ -196,35 +194,33 @@ static void
 logview_update_statusbar (LogviewWindow *logview, LogviewLog *active)
 {
   char *statusbar_text;
-  char *size, *modified, *index;
+  char *size, *modified, *timestring_utf8;
   time_t timestamp;
+  char timestring[255];
 
   if (active == NULL) {
     gtk_statusbar_pop (GTK_STATUSBAR (logview->priv->statusbar), 0);
     return;
   }
 
-  /* ctime returned string has "\n\0" causes statusbar display a invalid char */
   timestamp = logview_log_get_timestamp (active);
-  modified = ctime (&timestamp);
-  index = strrchr (modified, '\n');
-  if (index && *index != '\0')
-    *index = '\0';
+  strftime (timestring, sizeof (timestring), "%a %b %e %T %Y", localtime (&timestamp));
+  timestring_utf8 = g_locale_to_utf8 (timestring, -1, NULL, NULL, NULL);
 
-  modified = g_strdup_printf (_("last update: %s"), modified);
+  modified = g_strdup_printf (_("last update: %s"), timestring_utf8);
 
   size = g_format_size_for_display (logview_log_get_file_size (active));
   statusbar_text = g_strdup_printf (_("%d lines (%s) - %s"), 
                                     logview_log_get_cached_lines_number (active),
                                     size, modified);
 
-  if (statusbar_text) {
-    gtk_statusbar_pop (GTK_STATUSBAR (logview->priv->statusbar), 0);
-    gtk_statusbar_push (GTK_STATUSBAR (logview->priv->statusbar), 0, statusbar_text);
-    g_free (size);
-    g_free (modified);
-    g_free (statusbar_text);
-  }
+  gtk_statusbar_pop (GTK_STATUSBAR (logview->priv->statusbar), 0);
+  gtk_statusbar_push (GTK_STATUSBAR (logview->priv->statusbar), 0, statusbar_text);
+  
+  g_free (size);
+  g_free (timestring_utf8);
+  g_free (modified);
+  g_free (statusbar_text);
 }
 
 #define DEFAULT_LOGVIEW_FONT "Monospace 10"
@@ -1234,8 +1230,10 @@ message_area_create_error_box (LogviewWindow *window,
 
   window->priv->message_secondary = secondary_label;
 
-  gtk_message_area_set_contents (GTK_MESSAGE_AREA (message_area),
-                                 hbox_content);
+  gtk_container_add
+      (GTK_CONTAINER (gtk_info_bar_get_content_area
+                      (GTK_INFO_BAR (message_area))),
+       hbox_content);
 }
 
 static void
@@ -1259,7 +1257,7 @@ message_area_set_labels (LogviewWindow *window,
 }
 
 static void
-message_area_response_cb (GtkMessageArea *message_area,
+message_area_response_cb (GtkInfoBar *message_area,
                           int response_id, gpointer user_data)
 {
   LogviewWindow *window = user_data;
@@ -1371,11 +1369,10 @@ logview_window_init (LogviewWindow *logview)
   gtk_paned_pack2 (GTK_PANED (hpaned), main_view, TRUE, TRUE);
 
   /* second pane: error message area */
-  priv->message_area = gtk_message_area_new ();
+  priv->message_area = gtk_info_bar_new ();
   message_area_create_error_box (logview, priv->message_area);
-  gtk_message_area_add_stock_button_with_text (GTK_MESSAGE_AREA (priv->message_area),
-                                               _("Close"), GTK_STOCK_CLOSE,
-                                               GTK_RESPONSE_CLOSE);
+  gtk_info_bar_add_button (GTK_INFO_BAR (priv->message_area),
+                           GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
   gtk_box_pack_start (GTK_BOX (main_view), priv->message_area, FALSE, FALSE, 0);
 
   /* second pane: text view */
